pub struct CloseGlvShift {
pub reason: String,
}Expand description
Instruction argument
Fields
reason: StringTrait Implementations
Sourceimpl BorshDeserialize for CloseGlvShiftwhere
String: BorshDeserialize,
impl BorshDeserialize for CloseGlvShiftwhere
String: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CloseGlvShiftwhere
String: BorshSerialize,
impl BorshSerialize for CloseGlvShiftwhere
String: BorshSerialize,
Sourceimpl Discriminator for CloseGlvShift
impl Discriminator for CloseGlvShift
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for CloseGlvShift
impl InstructionData for CloseGlvShift