pub struct SetFeedConfigMarketStatusFlag {
pub provider: u8,
pub flag: u8,
pub enable: bool,
}Expand description
Instruction argument
Fields
provider: u8flag: u8enable: boolTrait Implementations
Sourceimpl BorshDeserialize for SetFeedConfigMarketStatusFlag
impl BorshDeserialize for SetFeedConfigMarketStatusFlag
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for SetFeedConfigMarketStatusFlag
impl Discriminator for SetFeedConfigMarketStatusFlag
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more