MarketModel

Struct MarketModel 

pub struct MarketModel { /* private fields */ }
Available on crate feature model only.
Market Model.

Implementations

Source

impl MarketModel

pub fn from_parts(market: Arc<Market>, supply: u64) -> Self

Create from parts.

pub fn is_pure(&self) -> bool

Get whether it is a pure market.

pub fn swap_pricing(&self) -> &SwapPricingKind

Get swap pricing kind.

pub fn with_swap_pricing<T>( &mut self, swap_pricing: SwapPricingKind, f: impl FnOnce(&mut Self) -> T, ) -> T

Execute a function with the specified swap pricing kind.

Panic Safety

This method uses RAII to ensure state is restored even if the closure panics.

pub fn with_vi_models<T>( &mut self, vi_map: &mut BTreeMap<Pubkey, VirtualInventoryModel>, f: impl FnOnce(&mut Self) -> T, ) -> T

Execute a function with virtual inventory models from a map.

This method temporarily replaces the virtual inventory models (for swaps and positions) of the MarketModel with models from the provided map, executes the provided function, and then restores the original values.

The virtual inventory models are looked up from the map using the market’s virtual_inventory_for_swaps and virtual_inventory_for_positions addresses.

Arguments
  • vi_map - A mutable reference to a map of Pubkey to VirtualInventoryModel
  • f - Function to execute with the temporary VI models
Returns

The return value of the function f

Note

The virtual inventory models are passed via a mutable reference to a map, allowing the caller to maintain access to the models and observe any state changes made during the function execution.

Panic Safety

This method uses RAII to ensure state is restored even if the closure panics.

Notes
  • If the MarketModel already has virtual inventory models attached (i.e. vi_for_swaps / vi_for_positions are Some), this function will not load VI models from vi_map and will not write any changes back to vi_map. In that case, only the existing in-model VI instances are used and mutated.
pub fn with_vis_if<T>( &mut self, vi_map: Option<&mut BTreeMap<Pubkey, VirtualInventoryModel>>, f: impl FnOnce(&mut Self) -> T, ) -> T

Execute a function with or without virtual inventories depending on the given map.

This is a small utility to unify the entry point of VI enable/disable logic so that callers do not need to duplicate branching between with_vi_models and with_vis_disabled.

pub fn with_vis_disabled<T>(&mut self, f: impl FnOnce(&mut Self) -> T) -> T

Execute a function with virtual inventories disabled.

Panic Safety

This method uses RAII to ensure state is restored even if the closure panics.

pub fn passed_in_seconds_for_funding(&self) -> Result<u64>

Returns the time in seconds since last funding fee state update.

pub fn into_empty_position( self, is_long: bool, collateral_token: Pubkey, ) -> Result<PositionModel>

Convert into an empty position model.

Notes
  • All position parameters unrelated to the model, such as owner and bump, use zeroed values.
pub fn into_empty_position_opts( self, is_long: bool, collateral_token: Pubkey, options: PositionOptions, ) -> Result<PositionModel>

Convert into an empty position model with options.

pub fn set_order_fee_discount_factor(&mut self, factor: u128)

Set order fee discount factor.

Methods from Deref<Target = Market>

pub fn name(&self) -> Result<&str>

Available on crate features utils and store and gmsol-utils only.

Get name.